package com.zyc.system.service;

import java.util.List;
import com.zyc.system.domain.CloudInstances;

/**
 * 云主机服务Service接口
 * 
 * @author zyc
 * @date 2024-12-26
 */
public interface ICloudInstancesService 
{
    /**
     * 查询云主机服务
     * 
     * @param id 云主机服务主键
     * @return 云主机服务
     */
    public CloudInstances selectCloudInstancesById(Integer id);

    /**
     * 查询云主机服务列表
     * 
     * @param cloudInstances 云主机服务
     * @return 云主机服务集合
     */
    public List<CloudInstances> selectCloudInstancesList(CloudInstances cloudInstances);

    /**
     * 新增云主机服务
     * 
     * @param cloudInstances 云主机服务
     * @return 结果
     */
    public int insertCloudInstances(CloudInstances cloudInstances);

    /**
     * 修改云主机服务
     * 
     * @param cloudInstances 云主机服务
     * @return 结果
     */
    public int updateCloudInstances(CloudInstances cloudInstances);

    /**
     * 批量删除云主机服务
     * 
     * @param ids 需要删除的云主机服务主键集合
     * @return 结果
     */
    public int deleteCloudInstancesByIds(Integer[] ids);

    /**
     * 删除云主机服务信息
     * 
     * @param id 云主机服务主键
     * @return 结果
     */
    public int deleteCloudInstancesById(Integer id);
}
