package com.zyc.web.controller.api;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zyc.common.annotation.Log;
import com.zyc.common.core.controller.BaseController;
import com.zyc.common.core.domain.AjaxResult;
import com.zyc.common.enums.BusinessType;
import com.zyc.system.domain.CloudInstances;
import com.zyc.system.service.ICloudInstancesService;
import com.zyc.common.utils.poi.ExcelUtil;
import com.zyc.common.core.page.TableDataInfo;

/**
 * 云主机服务Controller
 * 
 * @author zyc
 * @date 2024-12-26
 */
@RestController
@RequestMapping("/system/CloudInstancesController")
public class CloudInstancesController extends BaseController
{
    @Autowired
    private ICloudInstancesService cloudInstancesService;

    /**
     * 查询云主机服务列表
     */
    @PreAuthorize("@ss.hasPermi('system:instances:list')")
    @GetMapping("/list")
    public TableDataInfo list(CloudInstances cloudInstances)
    {
        startPage();
        List<CloudInstances> list = cloudInstancesService.selectCloudInstancesList(cloudInstances);
        return getDataTable(list);
    }

    /**
     * 导出云主机服务列表
     */
    @PreAuthorize("@ss.hasPermi('system:instances:export')")
    @Log(title = "云主机服务", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CloudInstances cloudInstances)
    {
        List<CloudInstances> list = cloudInstancesService.selectCloudInstancesList(cloudInstances);
        ExcelUtil<CloudInstances> util = new ExcelUtil<CloudInstances>(CloudInstances.class);
        util.exportExcel(response, list, "云主机服务数据");
    }

    /**
     * 获取云主机服务详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:instances:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(cloudInstancesService.selectCloudInstancesById(id));
    }

    /**
     * 新增云主机服务
     */
    @PreAuthorize("@ss.hasPermi('system:instances:add')")
    @Log(title = "云主机服务", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CloudInstances cloudInstances)
    {
        return toAjax(cloudInstancesService.insertCloudInstances(cloudInstances));
    }

    /**
     * 修改云主机服务
     */
    @PreAuthorize("@ss.hasPermi('system:instances:edit')")
    @Log(title = "云主机服务", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CloudInstances cloudInstances)
    {
        return toAjax(cloudInstancesService.updateCloudInstances(cloudInstances));
    }

    /**
     * 删除云主机服务
     */
    @PreAuthorize("@ss.hasPermi('system:instances:remove')")
    @Log(title = "云主机服务", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(cloudInstancesService.deleteCloudInstancesByIds(ids));
    }
}
